# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pycherwell.api_client import ApiClient
from pycherwell.exceptions import (
    ApiTypeError,
    ApiValueError
)


class UsersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def users_delete_user_batch_v1(self, user_batch_delete_request, **kwargs):  # noqa: E501
        """Delete a batch of users  # noqa: E501

        Operation to delete a batch of users. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_batch_v1(user_batch_delete_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchDeleteRequest user_batch_delete_request: Request object listing record IDs for users to be deleted and an error flag. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserBatchDeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_delete_user_batch_v1_with_http_info(user_batch_delete_request, **kwargs)  # noqa: E501

    def users_delete_user_batch_v1_with_http_info(self, user_batch_delete_request, **kwargs):  # noqa: E501
        """Delete a batch of users  # noqa: E501

        Operation to delete a batch of users. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_batch_v1_with_http_info(user_batch_delete_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchDeleteRequest user_batch_delete_request: Request object listing record IDs for users to be deleted and an error flag. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserBatchDeleteResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_batch_delete_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_delete_user_batch_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_batch_delete_request' is set
        if self.api_client.client_side_validation and ('user_batch_delete_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_batch_delete_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_batch_delete_request` when calling `users_delete_user_batch_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_batch_delete_request' in local_var_params:
            body_params = local_var_params['user_batch_delete_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/deleteuserbatch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserBatchDeleteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_delete_user_batch_v2(self, user_batch_delete_request, **kwargs):  # noqa: E501
        """Delete a batch of users  # noqa: E501

        Operation to delete a batch of users. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_batch_v2(user_batch_delete_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchDeleteRequest user_batch_delete_request: Request object listing record IDs for users to be deleted and an error flag. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserBatchDeleteV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_delete_user_batch_v2_with_http_info(user_batch_delete_request, **kwargs)  # noqa: E501

    def users_delete_user_batch_v2_with_http_info(self, user_batch_delete_request, **kwargs):  # noqa: E501
        """Delete a batch of users  # noqa: E501

        Operation to delete a batch of users. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_batch_v2_with_http_info(user_batch_delete_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchDeleteRequest user_batch_delete_request: Request object listing record IDs for users to be deleted and an error flag. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserBatchDeleteV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_batch_delete_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_delete_user_batch_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_batch_delete_request' is set
        if self.api_client.client_side_validation and ('user_batch_delete_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_batch_delete_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_batch_delete_request` when calling `users_delete_user_batch_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_batch_delete_request' in local_var_params:
            body_params = local_var_params['user_batch_delete_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/deleteuserbatch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserBatchDeleteV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_delete_user_v1(self, userrecordid, **kwargs):  # noqa: E501
        """Delete a user by record ID  # noqa: E501

        Operation to delete a user by record ID. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_v1(userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str userrecordid: Specify the record ID of the user you want to delete (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserDeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_delete_user_v1_with_http_info(userrecordid, **kwargs)  # noqa: E501

    def users_delete_user_v1_with_http_info(self, userrecordid, **kwargs):  # noqa: E501
        """Delete a user by record ID  # noqa: E501

        Operation to delete a user by record ID. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_v1_with_http_info(userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str userrecordid: Specify the record ID of the user you want to delete (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserDeleteResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['userrecordid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_delete_user_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'userrecordid' is set
        if self.api_client.client_side_validation and ('userrecordid' not in local_var_params or  # noqa: E501
                                                        local_var_params['userrecordid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `userrecordid` when calling `users_delete_user_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'userrecordid' in local_var_params:
            path_params['userrecordid'] = local_var_params['userrecordid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/deleteuser/userrecordid/{userrecordid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserDeleteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_delete_user_v2(self, userrecordid, **kwargs):  # noqa: E501
        """Delete a user by record ID  # noqa: E501

        Operation to delete a user by record ID. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_v2(userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str userrecordid: Specify the record ID of the user you want to delete (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserDeleteV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_delete_user_v2_with_http_info(userrecordid, **kwargs)  # noqa: E501

    def users_delete_user_v2_with_http_info(self, userrecordid, **kwargs):  # noqa: E501
        """Delete a user by record ID  # noqa: E501

        Operation to delete a user by record ID. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_v2_with_http_info(userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str userrecordid: Specify the record ID of the user you want to delete (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserDeleteV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['userrecordid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_delete_user_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'userrecordid' is set
        if self.api_client.client_side_validation and ('userrecordid' not in local_var_params or  # noqa: E501
                                                        local_var_params['userrecordid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `userrecordid` when calling `users_delete_user_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'userrecordid' in local_var_params:
            path_params['userrecordid'] = local_var_params['userrecordid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/deleteuser/userrecordid/{userrecordid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserDeleteV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_list_of_users(self, loginidfilter, **kwargs):  # noqa: E501
        """Get a list of all system users.  # noqa: E501

        Operation to get a list of all system users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_list_of_users(loginidfilter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginidfilter: Specify the login ID filter to apply to the users list. (required)
        :param bool stoponerror: Specify whether the operation is interrupted if retrieving any user causes an error.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_list_of_users_with_http_info(loginidfilter, **kwargs)  # noqa: E501

    def users_get_list_of_users_with_http_info(self, loginidfilter, **kwargs):  # noqa: E501
        """Get a list of all system users.  # noqa: E501

        Operation to get a list of all system users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_list_of_users_with_http_info(loginidfilter, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginidfilter: Specify the login ID filter to apply to the users list. (required)
        :param bool stoponerror: Specify whether the operation is interrupted if retrieving any user causes an error.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['loginidfilter', 'stoponerror']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_list_of_users" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'loginidfilter' is set
        if self.api_client.client_side_validation and ('loginidfilter' not in local_var_params or  # noqa: E501
                                                        local_var_params['loginidfilter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `loginidfilter` when calling `users_get_list_of_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'loginidfilter' in local_var_params and local_var_params['loginidfilter'] is not None:  # noqa: E501
            query_params.append(('loginidfilter', local_var_params['loginidfilter']))  # noqa: E501
        if 'stoponerror' in local_var_params and local_var_params['stoponerror'] is not None:  # noqa: E501
            query_params.append(('stoponerror', local_var_params['stoponerror']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getlistofusers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_batch_v1(self, user_batch_read_request, **kwargs):  # noqa: E501
        """Get user information in a batch  # noqa: E501

        Operation to get user information in a batch. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_batch_v1(user_batch_read_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchReadRequest user_batch_read_request: Request object that lists user record IDs or public IDs of users and an error flag. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserBatchReadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_batch_v1_with_http_info(user_batch_read_request, **kwargs)  # noqa: E501

    def users_get_user_batch_v1_with_http_info(self, user_batch_read_request, **kwargs):  # noqa: E501
        """Get user information in a batch  # noqa: E501

        Operation to get user information in a batch. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_batch_v1_with_http_info(user_batch_read_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchReadRequest user_batch_read_request: Request object that lists user record IDs or public IDs of users and an error flag. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserBatchReadResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_batch_read_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_batch_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_batch_read_request' is set
        if self.api_client.client_side_validation and ('user_batch_read_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_batch_read_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_batch_read_request` when calling `users_get_user_batch_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_batch_read_request' in local_var_params:
            body_params = local_var_params['user_batch_read_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getuserbatch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserBatchReadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_by_login_id_v1(self, loginid, **kwargs):  # noqa: E501
        """Get a user by login ID  # noqa: E501

        Operation to get detailed user information by login ID. Use to get user record IDs and account settings, for example. This operation has been deprecated by a V2 operation of the same name, but with query string parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_login_id_v1(loginid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginid: Specify the user's login ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_by_login_id_v1_with_http_info(loginid, **kwargs)  # noqa: E501

    def users_get_user_by_login_id_v1_with_http_info(self, loginid, **kwargs):  # noqa: E501
        """Get a user by login ID  # noqa: E501

        Operation to get detailed user information by login ID. Use to get user record IDs and account settings, for example. This operation has been deprecated by a V2 operation of the same name, but with query string parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_login_id_v1_with_http_info(loginid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginid: Specify the user's login ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(User, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['loginid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_by_login_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'loginid' is set
        if self.api_client.client_side_validation and ('loginid' not in local_var_params or  # noqa: E501
                                                        local_var_params['loginid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `loginid` when calling `users_get_user_by_login_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'loginid' in local_var_params:
            path_params['loginid'] = local_var_params['loginid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getuserbyloginid/loginid/{loginid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_by_login_id_v2(self, loginid, loginidtype, **kwargs):  # noqa: E501
        """Get a user by login ID and login ID type  # noqa: E501

        Operation to get detailed user information by login ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_login_id_v2(loginid, loginidtype, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginid: Specify the user's login ID. (required)
        :param str loginidtype: Specify the login ID type. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_by_login_id_v2_with_http_info(loginid, loginidtype, **kwargs)  # noqa: E501

    def users_get_user_by_login_id_v2_with_http_info(self, loginid, loginidtype, **kwargs):  # noqa: E501
        """Get a user by login ID and login ID type  # noqa: E501

        Operation to get detailed user information by login ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_login_id_v2_with_http_info(loginid, loginidtype, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginid: Specify the user's login ID. (required)
        :param str loginidtype: Specify the login ID type. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(User, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['loginid', 'loginidtype']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_by_login_id_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'loginid' is set
        if self.api_client.client_side_validation and ('loginid' not in local_var_params or  # noqa: E501
                                                        local_var_params['loginid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `loginid` when calling `users_get_user_by_login_id_v2`")  # noqa: E501
        # verify the required parameter 'loginidtype' is set
        if self.api_client.client_side_validation and ('loginidtype' not in local_var_params or  # noqa: E501
                                                        local_var_params['loginidtype'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `loginidtype` when calling `users_get_user_by_login_id_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'loginid' in local_var_params and local_var_params['loginid'] is not None:  # noqa: E501
            query_params.append(('loginid', local_var_params['loginid']))  # noqa: E501
        if 'loginidtype' in local_var_params and local_var_params['loginidtype'] is not None:  # noqa: E501
            query_params.append(('loginidtype', local_var_params['loginidtype']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getuserbyloginid', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_by_login_id_v3(self, loginid, loginidtype, **kwargs):  # noqa: E501
        """Get a user by login ID and login ID type  # noqa: E501

        Operation to get detailed user information by login ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_login_id_v3(loginid, loginidtype, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginid: Specify the user's login ID. (required)
        :param str loginidtype: Specify the login ID type. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_by_login_id_v3_with_http_info(loginid, loginidtype, **kwargs)  # noqa: E501

    def users_get_user_by_login_id_v3_with_http_info(self, loginid, loginidtype, **kwargs):  # noqa: E501
        """Get a user by login ID and login ID type  # noqa: E501

        Operation to get detailed user information by login ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_login_id_v3_with_http_info(loginid, loginidtype, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str loginid: Specify the user's login ID. (required)
        :param str loginidtype: Specify the login ID type. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserV2, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['loginid', 'loginidtype']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_by_login_id_v3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'loginid' is set
        if self.api_client.client_side_validation and ('loginid' not in local_var_params or  # noqa: E501
                                                        local_var_params['loginid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `loginid` when calling `users_get_user_by_login_id_v3`")  # noqa: E501
        # verify the required parameter 'loginidtype' is set
        if self.api_client.client_side_validation and ('loginidtype' not in local_var_params or  # noqa: E501
                                                        local_var_params['loginidtype'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `loginidtype` when calling `users_get_user_by_login_id_v3`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'loginid' in local_var_params and local_var_params['loginid'] is not None:  # noqa: E501
            query_params.append(('loginid', local_var_params['loginid']))  # noqa: E501
        if 'loginidtype' in local_var_params and local_var_params['loginidtype'] is not None:  # noqa: E501
            query_params.append(('loginidtype', local_var_params['loginidtype']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V3/getuserbyloginid', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_by_public_id_v1(self, publicid, **kwargs):  # noqa: E501
        """Get a user by public ID  # noqa: E501

        Operation to get detailed user information by public ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_public_id_v1(publicid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str publicid: Specify the user's public ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserReadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_by_public_id_v1_with_http_info(publicid, **kwargs)  # noqa: E501

    def users_get_user_by_public_id_v1_with_http_info(self, publicid, **kwargs):  # noqa: E501
        """Get a user by public ID  # noqa: E501

        Operation to get detailed user information by public ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_public_id_v1_with_http_info(publicid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str publicid: Specify the user's public ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserReadResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['publicid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_by_public_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'publicid' is set
        if self.api_client.client_side_validation and ('publicid' not in local_var_params or  # noqa: E501
                                                        local_var_params['publicid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `publicid` when calling `users_get_user_by_public_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'publicid' in local_var_params:
            path_params['publicid'] = local_var_params['publicid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getuserbypublicid/publicid/{publicid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserReadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_by_public_id_v2(self, publicid, **kwargs):  # noqa: E501
        """Get a user by public ID  # noqa: E501

        Operation to get detailed user information by public ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_public_id_v2(publicid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str publicid: Specify the user's public ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserReadV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_by_public_id_v2_with_http_info(publicid, **kwargs)  # noqa: E501

    def users_get_user_by_public_id_v2_with_http_info(self, publicid, **kwargs):  # noqa: E501
        """Get a user by public ID  # noqa: E501

        Operation to get detailed user information by public ID. Use to get user record IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_public_id_v2_with_http_info(publicid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str publicid: Specify the user's public ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserReadV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['publicid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_by_public_id_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'publicid' is set
        if self.api_client.client_side_validation and ('publicid' not in local_var_params or  # noqa: E501
                                                        local_var_params['publicid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `publicid` when calling `users_get_user_by_public_id_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'publicid' in local_var_params:
            path_params['publicid'] = local_var_params['publicid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getuserbypublicid/publicid/{publicid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserReadV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_user_by_rec_id(self, recid, **kwargs):  # noqa: E501
        """Get a user by record ID  # noqa: E501

        Operation to get detailed user information by record ID.  Use to get user public IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_rec_id(recid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str recid: Specify the user's record ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_get_user_by_rec_id_with_http_info(recid, **kwargs)  # noqa: E501

    def users_get_user_by_rec_id_with_http_info(self, recid, **kwargs):  # noqa: E501
        """Get a user by record ID  # noqa: E501

        Operation to get detailed user information by record ID.  Use to get user public IDs and account settings, for example.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_by_rec_id_with_http_info(recid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str recid: Specify the user's record ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserV2, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['recid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_user_by_rec_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'recid' is set
        if self.api_client.client_side_validation and ('recid' not in local_var_params or  # noqa: E501
                                                        local_var_params['recid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `recid` when calling `users_get_user_by_rec_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'recid' in local_var_params:
            path_params['recid'] = local_var_params['recid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getuserbyrecid/recid/{recid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_save_user_batch_v1(self, user_batch_save_request, **kwargs):  # noqa: E501
        """Create or update users in a batch  # noqa: E501

        Operation to create or update users in a batch. To update, specify record ID. To create, leave record ID empty.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_batch_v1(user_batch_save_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchSaveRequest user_batch_save_request: Request object listing user record IDs and an error flag. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserBatchSaveResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_save_user_batch_v1_with_http_info(user_batch_save_request, **kwargs)  # noqa: E501

    def users_save_user_batch_v1_with_http_info(self, user_batch_save_request, **kwargs):  # noqa: E501
        """Create or update users in a batch  # noqa: E501

        Operation to create or update users in a batch. To update, specify record ID. To create, leave record ID empty.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_batch_v1_with_http_info(user_batch_save_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchSaveRequest user_batch_save_request: Request object listing user record IDs and an error flag. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserBatchSaveResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_batch_save_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_save_user_batch_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_batch_save_request' is set
        if self.api_client.client_side_validation and ('user_batch_save_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_batch_save_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_batch_save_request` when calling `users_save_user_batch_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_batch_save_request' in local_var_params:
            body_params = local_var_params['user_batch_save_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/saveuserbatch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserBatchSaveResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_save_user_batch_v2(self, user_batch_save_v2_request, **kwargs):  # noqa: E501
        """Create or update users in a batch  # noqa: E501

        Operation to create or update users in a batch. To update, specify record ID. To create, leave record ID empty.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_batch_v2(user_batch_save_v2_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchSaveV2Request user_batch_save_v2_request: Request object listing user record IDs and an error flag. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserBatchSaveV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_save_user_batch_v2_with_http_info(user_batch_save_v2_request, **kwargs)  # noqa: E501

    def users_save_user_batch_v2_with_http_info(self, user_batch_save_v2_request, **kwargs):  # noqa: E501
        """Create or update users in a batch  # noqa: E501

        Operation to create or update users in a batch. To update, specify record ID. To create, leave record ID empty.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_batch_v2_with_http_info(user_batch_save_v2_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserBatchSaveV2Request user_batch_save_v2_request: Request object listing user record IDs and an error flag. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserBatchSaveV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_batch_save_v2_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_save_user_batch_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_batch_save_v2_request' is set
        if self.api_client.client_side_validation and ('user_batch_save_v2_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_batch_save_v2_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_batch_save_v2_request` when calling `users_save_user_batch_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_batch_save_v2_request' in local_var_params:
            body_params = local_var_params['user_batch_save_v2_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/saveuserbatch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserBatchSaveV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_save_user_v1(self, user_save_request, **kwargs):  # noqa: E501
        """Create or update a user  # noqa: E501

        Operation to create or update a user.  The response is a collection because if you use a public ID, more than one user could be updated since public IDs may not be unique.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_v1(user_save_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserSaveRequest user_save_request: Request object to specify user parameters and fields with values to be created or updated. The loginId and either the Business Object record ID or Public ID are required. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserSaveResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_save_user_v1_with_http_info(user_save_request, **kwargs)  # noqa: E501

    def users_save_user_v1_with_http_info(self, user_save_request, **kwargs):  # noqa: E501
        """Create or update a user  # noqa: E501

        Operation to create or update a user.  The response is a collection because if you use a public ID, more than one user could be updated since public IDs may not be unique.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_v1_with_http_info(user_save_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserSaveRequest user_save_request: Request object to specify user parameters and fields with values to be created or updated. The loginId and either the Business Object record ID or Public ID are required. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserSaveResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_save_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_save_user_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_save_request' is set
        if self.api_client.client_side_validation and ('user_save_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_save_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_save_request` when calling `users_save_user_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_save_request' in local_var_params:
            body_params = local_var_params['user_save_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/saveuser', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserSaveResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_save_user_v2(self, user_save_v2_request, **kwargs):  # noqa: E501
        """Create or update a user  # noqa: E501

        Operation to create or update a user.  The response is a collection because if you use a public ID, more than one user could be updated since public IDs may not be unique.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_v2(user_save_v2_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserSaveV2Request user_save_v2_request: Request object to specify user parameters and fields with values to be created or updated. The loginId and either the Business Object record ID or Public ID are required. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserSaveV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.users_save_user_v2_with_http_info(user_save_v2_request, **kwargs)  # noqa: E501

    def users_save_user_v2_with_http_info(self, user_save_v2_request, **kwargs):  # noqa: E501
        """Create or update a user  # noqa: E501

        Operation to create or update a user.  The response is a collection because if you use a public ID, more than one user could be updated since public IDs may not be unique.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_save_user_v2_with_http_info(user_save_v2_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserSaveV2Request user_save_v2_request: Request object to specify user parameters and fields with values to be created or updated. The loginId and either the Business Object record ID or Public ID are required. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserSaveV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_save_v2_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_save_user_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_save_v2_request' is set
        if self.api_client.client_side_validation and ('user_save_v2_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_save_v2_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_save_v2_request` when calling `users_save_user_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_save_v2_request' in local_var_params:
            body_params = local_var_params['user_save_v2_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/saveuser', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserSaveV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class ManagerItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'association': 'str',
        'description': 'str',
        'display_name': 'str',
        'gallery_image': 'str',
        'id': 'str',
        'links': 'list[Link]',
        'localized_scope_name': 'str',
        'name': 'str',
        'parent_folder': 'str',
        'parent_is_scope_folder': 'bool',
        'scope': 'str',
        'scope_owner': 'str',
        'stand_in_key': 'str'
    }

    attribute_map = {
        'association': 'association',
        'description': 'description',
        'display_name': 'displayName',
        'gallery_image': 'galleryImage',
        'id': 'id',
        'links': 'links',
        'localized_scope_name': 'localizedScopeName',
        'name': 'name',
        'parent_folder': 'parentFolder',
        'parent_is_scope_folder': 'parentIsScopeFolder',
        'scope': 'scope',
        'scope_owner': 'scopeOwner',
        'stand_in_key': 'standInKey'
    }

    def __init__(self, association=None, description=None, display_name=None, gallery_image=None, id=None, links=None, localized_scope_name=None, name=None, parent_folder=None, parent_is_scope_folder=None, scope=None, scope_owner=None, stand_in_key=None, local_vars_configuration=None):  # noqa: E501
        """ManagerItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._association = None
        self._description = None
        self._display_name = None
        self._gallery_image = None
        self._id = None
        self._links = None
        self._localized_scope_name = None
        self._name = None
        self._parent_folder = None
        self._parent_is_scope_folder = None
        self._scope = None
        self._scope_owner = None
        self._stand_in_key = None
        self.discriminator = None

        if association is not None:
            self.association = association
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if gallery_image is not None:
            self.gallery_image = gallery_image
        if id is not None:
            self.id = id
        if links is not None:
            self.links = links
        if localized_scope_name is not None:
            self.localized_scope_name = localized_scope_name
        if name is not None:
            self.name = name
        if parent_folder is not None:
            self.parent_folder = parent_folder
        if parent_is_scope_folder is not None:
            self.parent_is_scope_folder = parent_is_scope_folder
        if scope is not None:
            self.scope = scope
        if scope_owner is not None:
            self.scope_owner = scope_owner
        if stand_in_key is not None:
            self.stand_in_key = stand_in_key

    @property
    def association(self):
        """Gets the association of this ManagerItem.  # noqa: E501


        :return: The association of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._association

    @association.setter
    def association(self, association):
        """Sets the association of this ManagerItem.


        :param association: The association of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._association = association

    @property
    def description(self):
        """Gets the description of this ManagerItem.  # noqa: E501


        :return: The description of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ManagerItem.


        :param description: The description of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this ManagerItem.  # noqa: E501


        :return: The display_name of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this ManagerItem.


        :param display_name: The display_name of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def gallery_image(self):
        """Gets the gallery_image of this ManagerItem.  # noqa: E501


        :return: The gallery_image of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._gallery_image

    @gallery_image.setter
    def gallery_image(self, gallery_image):
        """Sets the gallery_image of this ManagerItem.


        :param gallery_image: The gallery_image of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._gallery_image = gallery_image

    @property
    def id(self):
        """Gets the id of this ManagerItem.  # noqa: E501


        :return: The id of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ManagerItem.


        :param id: The id of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def links(self):
        """Gets the links of this ManagerItem.  # noqa: E501


        :return: The links of this ManagerItem.  # noqa: E501
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this ManagerItem.


        :param links: The links of this ManagerItem.  # noqa: E501
        :type: list[Link]
        """

        self._links = links

    @property
    def localized_scope_name(self):
        """Gets the localized_scope_name of this ManagerItem.  # noqa: E501


        :return: The localized_scope_name of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._localized_scope_name

    @localized_scope_name.setter
    def localized_scope_name(self, localized_scope_name):
        """Sets the localized_scope_name of this ManagerItem.


        :param localized_scope_name: The localized_scope_name of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._localized_scope_name = localized_scope_name

    @property
    def name(self):
        """Gets the name of this ManagerItem.  # noqa: E501


        :return: The name of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ManagerItem.


        :param name: The name of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parent_folder(self):
        """Gets the parent_folder of this ManagerItem.  # noqa: E501


        :return: The parent_folder of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder

    @parent_folder.setter
    def parent_folder(self, parent_folder):
        """Sets the parent_folder of this ManagerItem.


        :param parent_folder: The parent_folder of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._parent_folder = parent_folder

    @property
    def parent_is_scope_folder(self):
        """Gets the parent_is_scope_folder of this ManagerItem.  # noqa: E501


        :return: The parent_is_scope_folder of this ManagerItem.  # noqa: E501
        :rtype: bool
        """
        return self._parent_is_scope_folder

    @parent_is_scope_folder.setter
    def parent_is_scope_folder(self, parent_is_scope_folder):
        """Sets the parent_is_scope_folder of this ManagerItem.


        :param parent_is_scope_folder: The parent_is_scope_folder of this ManagerItem.  # noqa: E501
        :type: bool
        """

        self._parent_is_scope_folder = parent_is_scope_folder

    @property
    def scope(self):
        """Gets the scope of this ManagerItem.  # noqa: E501


        :return: The scope of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this ManagerItem.


        :param scope: The scope of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def scope_owner(self):
        """Gets the scope_owner of this ManagerItem.  # noqa: E501


        :return: The scope_owner of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._scope_owner

    @scope_owner.setter
    def scope_owner(self, scope_owner):
        """Sets the scope_owner of this ManagerItem.


        :param scope_owner: The scope_owner of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._scope_owner = scope_owner

    @property
    def stand_in_key(self):
        """Gets the stand_in_key of this ManagerItem.  # noqa: E501


        :return: The stand_in_key of this ManagerItem.  # noqa: E501
        :rtype: str
        """
        return self._stand_in_key

    @stand_in_key.setter
    def stand_in_key(self, stand_in_key):
        """Sets the stand_in_key of this ManagerItem.


        :param stand_in_key: The stand_in_key of this ManagerItem.  # noqa: E501
        :type: str
        """

        self._stand_in_key = stand_in_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ManagerItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ManagerItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.queues_api import QueuesApi  # noqa: E501
from pycherwell.rest import ApiException


class TestQueuesApi(unittest.TestCase):
    """QueuesApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.queues_api.QueuesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_queues_add_item_to_queue_v1(self):
        """Test case for queues_add_item_to_queue_v1

        Add a Business Object to a queue  # noqa: E501
        """
        pass

    def test_queues_check_in_queue_item_v1(self):
        """Test case for queues_check_in_queue_item_v1

        Check a Business Object in to a queue  # noqa: E501
        """
        pass

    def test_queues_check_out_queue_item_v1(self):
        """Test case for queues_check_out_queue_item_v1

        Check a Business Object out of a queue  # noqa: E501
        """
        pass

    def test_queues_get_queues_folder_v1(self):
        """Test case for queues_get_queues_folder_v1

        Get available queues.  # noqa: E501
        """
        pass

    def test_queues_get_queues_scope_owner_v1(self):
        """Test case for queues_get_queues_scope_owner_v1

        Get available queues.  # noqa: E501
        """
        pass

    def test_queues_get_queues_scope_v1(self):
        """Test case for queues_get_queues_scope_v1

        Get available queues.  # noqa: E501
        """
        pass

    def test_queues_get_queues_v1(self):
        """Test case for queues_get_queues_v1

        Get available queues.  # noqa: E501
        """
        pass

    def test_queues_remove_item_from_queue_v1(self):
        """Test case for queues_remove_item_from_queue_v1

        Remove an item from a queue  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301
from os import path


# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

__version__ = '1.0.9'

this_directory = path.abspath(path.dirname(__file__))
try:
    with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except:
    with open(path.join(this_directory, 'README.md')) as f:
        long_description = f.read()

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "requests"]

setup(
    name='pycherwell',
    version=__version__,
    description="Cherwell REST API Client and Library",
    author="Paul Greenberg",
    author_email="greenpau@outlook.com",
    url="https://github.com/greenpau/pycherwell",
    keywords=["OpenAPI", "OpenAPI-Generator", "Cherwell REST API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    scripts=['cherwell-client'],
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
)



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class UserSaveRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_locked': 'bool',
        'bus_ob_id': 'str',
        'bus_ob_public_id': 'str',
        'bus_ob_rec_id': 'str',
        'display_name': 'str',
        'error': 'str',
        'error_code': 'str',
        'has_error': 'bool',
        'ldap_required': 'bool',
        'login_id': 'str',
        'next_password_reset_date': 'datetime',
        'password': 'str',
        'password_never_expires': 'bool',
        'security_group_id': 'str',
        'user_cannot_change_password': 'bool',
        'user_info_fields': 'list[FieldTemplateItem]',
        'user_must_change_password_at_next_login': 'bool',
        'windows_user_id': 'str'
    }

    attribute_map = {
        'account_locked': 'accountLocked',
        'bus_ob_id': 'busObId',
        'bus_ob_public_id': 'busObPublicId',
        'bus_ob_rec_id': 'busObRecId',
        'display_name': 'displayName',
        'error': 'error',
        'error_code': 'errorCode',
        'has_error': 'hasError',
        'ldap_required': 'ldapRequired',
        'login_id': 'loginId',
        'next_password_reset_date': 'nextPasswordResetDate',
        'password': 'password',
        'password_never_expires': 'passwordNeverExpires',
        'security_group_id': 'securityGroupId',
        'user_cannot_change_password': 'userCannotChangePassword',
        'user_info_fields': 'userInfoFields',
        'user_must_change_password_at_next_login': 'userMustChangePasswordAtNextLogin',
        'windows_user_id': 'windowsUserId'
    }

    def __init__(self, account_locked=None, bus_ob_id=None, bus_ob_public_id=None, bus_ob_rec_id=None, display_name=None, error=None, error_code=None, has_error=None, ldap_required=None, login_id=None, next_password_reset_date=None, password=None, password_never_expires=None, security_group_id=None, user_cannot_change_password=None, user_info_fields=None, user_must_change_password_at_next_login=None, windows_user_id=None, local_vars_configuration=None):  # noqa: E501
        """UserSaveRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_locked = None
        self._bus_ob_id = None
        self._bus_ob_public_id = None
        self._bus_ob_rec_id = None
        self._display_name = None
        self._error = None
        self._error_code = None
        self._has_error = None
        self._ldap_required = None
        self._login_id = None
        self._next_password_reset_date = None
        self._password = None
        self._password_never_expires = None
        self._security_group_id = None
        self._user_cannot_change_password = None
        self._user_info_fields = None
        self._user_must_change_password_at_next_login = None
        self._windows_user_id = None
        self.discriminator = None

        if account_locked is not None:
            self.account_locked = account_locked
        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if bus_ob_public_id is not None:
            self.bus_ob_public_id = bus_ob_public_id
        if bus_ob_rec_id is not None:
            self.bus_ob_rec_id = bus_ob_rec_id
        if display_name is not None:
            self.display_name = display_name
        if error is not None:
            self.error = error
        if error_code is not None:
            self.error_code = error_code
        if has_error is not None:
            self.has_error = has_error
        if ldap_required is not None:
            self.ldap_required = ldap_required
        if login_id is not None:
            self.login_id = login_id
        if next_password_reset_date is not None:
            self.next_password_reset_date = next_password_reset_date
        if password is not None:
            self.password = password
        if password_never_expires is not None:
            self.password_never_expires = password_never_expires
        if security_group_id is not None:
            self.security_group_id = security_group_id
        if user_cannot_change_password is not None:
            self.user_cannot_change_password = user_cannot_change_password
        if user_info_fields is not None:
            self.user_info_fields = user_info_fields
        if user_must_change_password_at_next_login is not None:
            self.user_must_change_password_at_next_login = user_must_change_password_at_next_login
        if windows_user_id is not None:
            self.windows_user_id = windows_user_id

    @property
    def account_locked(self):
        """Gets the account_locked of this UserSaveRequest.  # noqa: E501


        :return: The account_locked of this UserSaveRequest.  # noqa: E501
        :rtype: bool
        """
        return self._account_locked

    @account_locked.setter
    def account_locked(self, account_locked):
        """Sets the account_locked of this UserSaveRequest.


        :param account_locked: The account_locked of this UserSaveRequest.  # noqa: E501
        :type: bool
        """

        self._account_locked = account_locked

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this UserSaveRequest.  # noqa: E501


        :return: The bus_ob_id of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this UserSaveRequest.


        :param bus_ob_id: The bus_ob_id of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def bus_ob_public_id(self):
        """Gets the bus_ob_public_id of this UserSaveRequest.  # noqa: E501


        :return: The bus_ob_public_id of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_public_id

    @bus_ob_public_id.setter
    def bus_ob_public_id(self, bus_ob_public_id):
        """Sets the bus_ob_public_id of this UserSaveRequest.


        :param bus_ob_public_id: The bus_ob_public_id of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._bus_ob_public_id = bus_ob_public_id

    @property
    def bus_ob_rec_id(self):
        """Gets the bus_ob_rec_id of this UserSaveRequest.  # noqa: E501


        :return: The bus_ob_rec_id of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_rec_id

    @bus_ob_rec_id.setter
    def bus_ob_rec_id(self, bus_ob_rec_id):
        """Sets the bus_ob_rec_id of this UserSaveRequest.


        :param bus_ob_rec_id: The bus_ob_rec_id of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._bus_ob_rec_id = bus_ob_rec_id

    @property
    def display_name(self):
        """Gets the display_name of this UserSaveRequest.  # noqa: E501


        :return: The display_name of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UserSaveRequest.


        :param display_name: The display_name of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def error(self):
        """Gets the error of this UserSaveRequest.  # noqa: E501


        :return: The error of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this UserSaveRequest.


        :param error: The error of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def error_code(self):
        """Gets the error_code of this UserSaveRequest.  # noqa: E501


        :return: The error_code of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this UserSaveRequest.


        :param error_code: The error_code of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def has_error(self):
        """Gets the has_error of this UserSaveRequest.  # noqa: E501


        :return: The has_error of this UserSaveRequest.  # noqa: E501
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """Sets the has_error of this UserSaveRequest.


        :param has_error: The has_error of this UserSaveRequest.  # noqa: E501
        :type: bool
        """

        self._has_error = has_error

    @property
    def ldap_required(self):
        """Gets the ldap_required of this UserSaveRequest.  # noqa: E501


        :return: The ldap_required of this UserSaveRequest.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_required

    @ldap_required.setter
    def ldap_required(self, ldap_required):
        """Sets the ldap_required of this UserSaveRequest.


        :param ldap_required: The ldap_required of this UserSaveRequest.  # noqa: E501
        :type: bool
        """

        self._ldap_required = ldap_required

    @property
    def login_id(self):
        """Gets the login_id of this UserSaveRequest.  # noqa: E501


        :return: The login_id of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._login_id

    @login_id.setter
    def login_id(self, login_id):
        """Sets the login_id of this UserSaveRequest.


        :param login_id: The login_id of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._login_id = login_id

    @property
    def next_password_reset_date(self):
        """Gets the next_password_reset_date of this UserSaveRequest.  # noqa: E501


        :return: The next_password_reset_date of this UserSaveRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._next_password_reset_date

    @next_password_reset_date.setter
    def next_password_reset_date(self, next_password_reset_date):
        """Sets the next_password_reset_date of this UserSaveRequest.


        :param next_password_reset_date: The next_password_reset_date of this UserSaveRequest.  # noqa: E501
        :type: datetime
        """

        self._next_password_reset_date = next_password_reset_date

    @property
    def password(self):
        """Gets the password of this UserSaveRequest.  # noqa: E501


        :return: The password of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UserSaveRequest.


        :param password: The password of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def password_never_expires(self):
        """Gets the password_never_expires of this UserSaveRequest.  # noqa: E501


        :return: The password_never_expires of this UserSaveRequest.  # noqa: E501
        :rtype: bool
        """
        return self._password_never_expires

    @password_never_expires.setter
    def password_never_expires(self, password_never_expires):
        """Sets the password_never_expires of this UserSaveRequest.


        :param password_never_expires: The password_never_expires of this UserSaveRequest.  # noqa: E501
        :type: bool
        """

        self._password_never_expires = password_never_expires

    @property
    def security_group_id(self):
        """Gets the security_group_id of this UserSaveRequest.  # noqa: E501


        :return: The security_group_id of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        """Sets the security_group_id of this UserSaveRequest.


        :param security_group_id: The security_group_id of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._security_group_id = security_group_id

    @property
    def user_cannot_change_password(self):
        """Gets the user_cannot_change_password of this UserSaveRequest.  # noqa: E501


        :return: The user_cannot_change_password of this UserSaveRequest.  # noqa: E501
        :rtype: bool
        """
        return self._user_cannot_change_password

    @user_cannot_change_password.setter
    def user_cannot_change_password(self, user_cannot_change_password):
        """Sets the user_cannot_change_password of this UserSaveRequest.


        :param user_cannot_change_password: The user_cannot_change_password of this UserSaveRequest.  # noqa: E501
        :type: bool
        """

        self._user_cannot_change_password = user_cannot_change_password

    @property
    def user_info_fields(self):
        """Gets the user_info_fields of this UserSaveRequest.  # noqa: E501


        :return: The user_info_fields of this UserSaveRequest.  # noqa: E501
        :rtype: list[FieldTemplateItem]
        """
        return self._user_info_fields

    @user_info_fields.setter
    def user_info_fields(self, user_info_fields):
        """Sets the user_info_fields of this UserSaveRequest.


        :param user_info_fields: The user_info_fields of this UserSaveRequest.  # noqa: E501
        :type: list[FieldTemplateItem]
        """

        self._user_info_fields = user_info_fields

    @property
    def user_must_change_password_at_next_login(self):
        """Gets the user_must_change_password_at_next_login of this UserSaveRequest.  # noqa: E501


        :return: The user_must_change_password_at_next_login of this UserSaveRequest.  # noqa: E501
        :rtype: bool
        """
        return self._user_must_change_password_at_next_login

    @user_must_change_password_at_next_login.setter
    def user_must_change_password_at_next_login(self, user_must_change_password_at_next_login):
        """Sets the user_must_change_password_at_next_login of this UserSaveRequest.


        :param user_must_change_password_at_next_login: The user_must_change_password_at_next_login of this UserSaveRequest.  # noqa: E501
        :type: bool
        """

        self._user_must_change_password_at_next_login = user_must_change_password_at_next_login

    @property
    def windows_user_id(self):
        """Gets the windows_user_id of this UserSaveRequest.  # noqa: E501


        :return: The windows_user_id of this UserSaveRequest.  # noqa: E501
        :rtype: str
        """
        return self._windows_user_id

    @windows_user_id.setter
    def windows_user_id(self, windows_user_id):
        """Sets the windows_user_id of this UserSaveRequest.


        :param windows_user_id: The windows_user_id of this UserSaveRequest.  # noqa: E501
        :type: str
        """

        self._windows_user_id = windows_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSaveRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSaveRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from pycherwell.models.action import Action
from pycherwell.models.add_item_to_queue_request import AddItemToQueueRequest
from pycherwell.models.add_item_to_queue_response import AddItemToQueueResponse
from pycherwell.models.add_user_to_team_by_batch_request import AddUserToTeamByBatchRequest
from pycherwell.models.add_user_to_team_by_batch_response import AddUserToTeamByBatchResponse
from pycherwell.models.add_user_to_team_request import AddUserToTeamRequest
from pycherwell.models.add_user_to_team_response import AddUserToTeamResponse
from pycherwell.models.api_client_setting_response import ApiClientSettingResponse
from pycherwell.models.association import Association
from pycherwell.models.attachment import Attachment
from pycherwell.models.attachments_request import AttachmentsRequest
from pycherwell.models.attachments_response import AttachmentsResponse
from pycherwell.models.barcode_lookup_response import BarcodeLookupResponse
from pycherwell.models.batch_delete_request import BatchDeleteRequest
from pycherwell.models.batch_delete_response import BatchDeleteResponse
from pycherwell.models.batch_read_request import BatchReadRequest
from pycherwell.models.batch_read_response import BatchReadResponse
from pycherwell.models.batch_save_request import BatchSaveRequest
from pycherwell.models.batch_save_response import BatchSaveResponse
from pycherwell.models.bus_obs_for_view_response import BusObsForViewResponse
from pycherwell.models.business_object_permission import BusinessObjectPermission
from pycherwell.models.changed_limit import ChangedLimit
from pycherwell.models.check_in_queue_item_request import CheckInQueueItemRequest
from pycherwell.models.check_in_queue_item_response import CheckInQueueItemResponse
from pycherwell.models.check_out_queue_item_request import CheckOutQueueItemRequest
from pycherwell.models.check_out_queue_item_response import CheckOutQueueItemResponse
from pycherwell.models.client_security_settings_response import ClientSecuritySettingsResponse
from pycherwell.models.delete_api_client_settings_response import DeleteApiClientSettingsResponse
from pycherwell.models.delete_request import DeleteRequest
from pycherwell.models.delete_response import DeleteResponse
from pycherwell.models.export_search_results_request import ExportSearchResultsRequest
from pycherwell.models.field import Field
from pycherwell.models.field_definition import FieldDefinition
from pycherwell.models.field_permission import FieldPermission
from pycherwell.models.field_template_item import FieldTemplateItem
from pycherwell.models.field_validation_error import FieldValidationError
from pycherwell.models.field_values_lookup_request import FieldValuesLookupRequest
from pycherwell.models.field_values_lookup_response import FieldValuesLookupResponse
from pycherwell.models.filter_info import FilterInfo
from pycherwell.models.get_api_client_settings_response import GetApiClientSettingsResponse
from pycherwell.models.get_api_client_settings_response_item import GetApiClientSettingsResponseItem
from pycherwell.models.get_security_group_business_object_permissions_response import GetSecurityGroupBusinessObjectPermissionsResponse
from pycherwell.models.grid_definition import GridDefinition
from pycherwell.models.key_value_pair_string_string import KeyValuePairStringString
from pycherwell.models.link import Link
from pycherwell.models.location import Location
from pycherwell.models.log_batch_request import LogBatchRequest
from pycherwell.models.log_request import LogRequest
from pycherwell.models.manager_data import ManagerData
from pycherwell.models.manager_folder import ManagerFolder
from pycherwell.models.manager_item import ManagerItem
from pycherwell.models.mobile_credentials_mode_response import MobileCredentialsModeResponse
from pycherwell.models.mobile_form_response import MobileFormResponse
from pycherwell.models.name_value_pair import NameValuePair
from pycherwell.models.notification_trigger import NotificationTrigger
from pycherwell.models.prompt import Prompt
from pycherwell.models.prompt_value import PromptValue
from pycherwell.models.quick_search_by_id_request import QuickSearchByIdRequest
from pycherwell.models.quick_search_config_saved_request import QuickSearchConfigSavedRequest
from pycherwell.models.quick_search_configuration_request import QuickSearchConfigurationRequest
from pycherwell.models.quick_search_configuration_response import QuickSearchConfigurationResponse
from pycherwell.models.quick_search_item import QuickSearchItem
from pycherwell.models.quick_search_request import QuickSearchRequest
from pycherwell.models.quick_search_response import QuickSearchResponse
from pycherwell.models.quick_search_specific_by_id_request import QuickSearchSpecificByIdRequest
from pycherwell.models.quick_search_specific_request import QuickSearchSpecificRequest
from pycherwell.models.read_request import ReadRequest
from pycherwell.models.read_response import ReadResponse
from pycherwell.models.related_business_object_request import RelatedBusinessObjectRequest
from pycherwell.models.related_business_object_response import RelatedBusinessObjectResponse
from pycherwell.models.related_save_request import RelatedSaveRequest
from pycherwell.models.related_save_response import RelatedSaveResponse
from pycherwell.models.relationship import Relationship
from pycherwell.models.remove_customer_from_workgroup_response import RemoveCustomerFromWorkgroupResponse
from pycherwell.models.remove_item_from_queue_request import RemoveItemFromQueueRequest
from pycherwell.models.remove_item_from_queue_response import RemoveItemFromQueueResponse
from pycherwell.models.remove_user_from_team_response import RemoveUserFromTeamResponse
from pycherwell.models.right import Right
from pycherwell.models.right_category import RightCategory
from pycherwell.models.role import Role
from pycherwell.models.role_read_response import RoleReadResponse
from pycherwell.models.role_read_v2_response import RoleReadV2Response
from pycherwell.models.save_api_client_setting_request import SaveApiClientSettingRequest
from pycherwell.models.save_bus_ob_attachment_request import SaveBusObAttachmentRequest
from pycherwell.models.save_gallery_image_request import SaveGalleryImageRequest
from pycherwell.models.save_gallery_image_response import SaveGalleryImageResponse
from pycherwell.models.save_link_attachment_request import SaveLinkAttachmentRequest
from pycherwell.models.save_request import SaveRequest
from pycherwell.models.save_response import SaveResponse
from pycherwell.models.save_stored_value_request import SaveStoredValueRequest
from pycherwell.models.save_team_member_request import SaveTeamMemberRequest
from pycherwell.models.save_team_member_response import SaveTeamMemberResponse
from pycherwell.models.save_url_attachment_request import SaveUrlAttachmentRequest
from pycherwell.models.save_workgroup_member_request import SaveWorkgroupMemberRequest
from pycherwell.models.save_workgroup_member_response import SaveWorkgroupMemberResponse
from pycherwell.models.schema_response import SchemaResponse
from pycherwell.models.search_folder import SearchFolder
from pycherwell.models.search_item import SearchItem
from pycherwell.models.search_item_response import SearchItemResponse
from pycherwell.models.search_results_request import SearchResultsRequest
from pycherwell.models.search_results_response import SearchResultsResponse
from pycherwell.models.search_results_row import SearchResultsRow
from pycherwell.models.search_results_table_response import SearchResultsTableResponse
from pycherwell.models.section import Section
from pycherwell.models.section_field import SectionField
from pycherwell.models.security_group import SecurityGroup
from pycherwell.models.security_group_response import SecurityGroupResponse
from pycherwell.models.security_group_v2_response import SecurityGroupV2Response
from pycherwell.models.security_right_categories_response import SecurityRightCategoriesResponse
from pycherwell.models.security_rights_response import SecurityRightsResponse
from pycherwell.models.service_info_response import ServiceInfoResponse
from pycherwell.models.simple_results_list import SimpleResultsList
from pycherwell.models.simple_results_list_group import SimpleResultsListGroup
from pycherwell.models.simple_results_list_item import SimpleResultsListItem
from pycherwell.models.sort_info import SortInfo
from pycherwell.models.stored_value_response import StoredValueResponse
from pycherwell.models.summary import Summary
from pycherwell.models.team import Team
from pycherwell.models.team_response import TeamResponse
from pycherwell.models.team_save_request import TeamSaveRequest
from pycherwell.models.team_save_response import TeamSaveResponse
from pycherwell.models.teams_response import TeamsResponse
from pycherwell.models.teams_v2_response import TeamsV2Response
from pycherwell.models.template_request import TemplateRequest
from pycherwell.models.template_response import TemplateResponse
from pycherwell.models.user import User
from pycherwell.models.user_batch_delete_request import UserBatchDeleteRequest
from pycherwell.models.user_batch_delete_response import UserBatchDeleteResponse
from pycherwell.models.user_batch_delete_v2_response import UserBatchDeleteV2Response
from pycherwell.models.user_batch_read_request import UserBatchReadRequest
from pycherwell.models.user_batch_read_response import UserBatchReadResponse
from pycherwell.models.user_batch_save_request import UserBatchSaveRequest
from pycherwell.models.user_batch_save_response import UserBatchSaveResponse
from pycherwell.models.user_batch_save_v2_request import UserBatchSaveV2Request
from pycherwell.models.user_batch_save_v2_response import UserBatchSaveV2Response
from pycherwell.models.user_delete_response import UserDeleteResponse
from pycherwell.models.user_delete_v2_response import UserDeleteV2Response
from pycherwell.models.user_list_response import UserListResponse
from pycherwell.models.user_read_request import UserReadRequest
from pycherwell.models.user_read_response import UserReadResponse
from pycherwell.models.user_read_v2_response import UserReadV2Response
from pycherwell.models.user_save_request import UserSaveRequest
from pycherwell.models.user_save_response import UserSaveResponse
from pycherwell.models.user_save_v2_request import UserSaveV2Request
from pycherwell.models.user_save_v2_response import UserSaveV2Response
from pycherwell.models.user_v2 import UserV2
from pycherwell.models.view import View
from pycherwell.models.view_summary import ViewSummary
from pycherwell.models.views_response import ViewsResponse



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SimpleResultsListItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bus_ob_id': 'str',
        'bus_ob_rec_id': 'str',
        'doc_repository_item_id': 'str',
        'gallery_image': 'str',
        'links': 'list[Link]',
        'public_id': 'str',
        'scope': 'str',
        'scope_owner': 'str',
        'sub_title': 'str',
        'text': 'str',
        'title': 'str'
    }

    attribute_map = {
        'bus_ob_id': 'busObId',
        'bus_ob_rec_id': 'busObRecId',
        'doc_repository_item_id': 'docRepositoryItemId',
        'gallery_image': 'galleryImage',
        'links': 'links',
        'public_id': 'publicId',
        'scope': 'scope',
        'scope_owner': 'scopeOwner',
        'sub_title': 'subTitle',
        'text': 'text',
        'title': 'title'
    }

    def __init__(self, bus_ob_id=None, bus_ob_rec_id=None, doc_repository_item_id=None, gallery_image=None, links=None, public_id=None, scope=None, scope_owner=None, sub_title=None, text=None, title=None, local_vars_configuration=None):  # noqa: E501
        """SimpleResultsListItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bus_ob_id = None
        self._bus_ob_rec_id = None
        self._doc_repository_item_id = None
        self._gallery_image = None
        self._links = None
        self._public_id = None
        self._scope = None
        self._scope_owner = None
        self._sub_title = None
        self._text = None
        self._title = None
        self.discriminator = None

        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if bus_ob_rec_id is not None:
            self.bus_ob_rec_id = bus_ob_rec_id
        if doc_repository_item_id is not None:
            self.doc_repository_item_id = doc_repository_item_id
        if gallery_image is not None:
            self.gallery_image = gallery_image
        if links is not None:
            self.links = links
        if public_id is not None:
            self.public_id = public_id
        if scope is not None:
            self.scope = scope
        if scope_owner is not None:
            self.scope_owner = scope_owner
        if sub_title is not None:
            self.sub_title = sub_title
        if text is not None:
            self.text = text
        if title is not None:
            self.title = title

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this SimpleResultsListItem.  # noqa: E501


        :return: The bus_ob_id of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this SimpleResultsListItem.


        :param bus_ob_id: The bus_ob_id of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def bus_ob_rec_id(self):
        """Gets the bus_ob_rec_id of this SimpleResultsListItem.  # noqa: E501


        :return: The bus_ob_rec_id of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_rec_id

    @bus_ob_rec_id.setter
    def bus_ob_rec_id(self, bus_ob_rec_id):
        """Sets the bus_ob_rec_id of this SimpleResultsListItem.


        :param bus_ob_rec_id: The bus_ob_rec_id of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._bus_ob_rec_id = bus_ob_rec_id

    @property
    def doc_repository_item_id(self):
        """Gets the doc_repository_item_id of this SimpleResultsListItem.  # noqa: E501


        :return: The doc_repository_item_id of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._doc_repository_item_id

    @doc_repository_item_id.setter
    def doc_repository_item_id(self, doc_repository_item_id):
        """Sets the doc_repository_item_id of this SimpleResultsListItem.


        :param doc_repository_item_id: The doc_repository_item_id of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._doc_repository_item_id = doc_repository_item_id

    @property
    def gallery_image(self):
        """Gets the gallery_image of this SimpleResultsListItem.  # noqa: E501


        :return: The gallery_image of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._gallery_image

    @gallery_image.setter
    def gallery_image(self, gallery_image):
        """Sets the gallery_image of this SimpleResultsListItem.


        :param gallery_image: The gallery_image of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._gallery_image = gallery_image

    @property
    def links(self):
        """Gets the links of this SimpleResultsListItem.  # noqa: E501


        :return: The links of this SimpleResultsListItem.  # noqa: E501
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this SimpleResultsListItem.


        :param links: The links of this SimpleResultsListItem.  # noqa: E501
        :type: list[Link]
        """

        self._links = links

    @property
    def public_id(self):
        """Gets the public_id of this SimpleResultsListItem.  # noqa: E501


        :return: The public_id of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this SimpleResultsListItem.


        :param public_id: The public_id of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def scope(self):
        """Gets the scope of this SimpleResultsListItem.  # noqa: E501


        :return: The scope of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this SimpleResultsListItem.


        :param scope: The scope of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def scope_owner(self):
        """Gets the scope_owner of this SimpleResultsListItem.  # noqa: E501


        :return: The scope_owner of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._scope_owner

    @scope_owner.setter
    def scope_owner(self, scope_owner):
        """Sets the scope_owner of this SimpleResultsListItem.


        :param scope_owner: The scope_owner of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._scope_owner = scope_owner

    @property
    def sub_title(self):
        """Gets the sub_title of this SimpleResultsListItem.  # noqa: E501


        :return: The sub_title of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._sub_title

    @sub_title.setter
    def sub_title(self, sub_title):
        """Sets the sub_title of this SimpleResultsListItem.


        :param sub_title: The sub_title of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._sub_title = sub_title

    @property
    def text(self):
        """Gets the text of this SimpleResultsListItem.  # noqa: E501


        :return: The text of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this SimpleResultsListItem.


        :param text: The text of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def title(self):
        """Gets the title of this SimpleResultsListItem.  # noqa: E501


        :return: The title of this SimpleResultsListItem.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this SimpleResultsListItem.


        :param title: The title of this SimpleResultsListItem.  # noqa: E501
        :type: str
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleResultsListItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SimpleResultsListItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Prompt(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allow_values_only': 'bool',
        'bus_ob_id': 'str',
        'collection_store_entire_row': 'str',
        'collection_value_field': 'str',
        'constraint_xml': 'str',
        'contents': 'str',
        'default': 'str',
        'field_id': 'str',
        'is_date_range': 'bool',
        'list_display_option': 'str',
        'list_return_field_id': 'str',
        'multi_line': 'bool',
        'prompt_id': 'str',
        'prompt_type': 'str',
        'prompt_type_name': 'str',
        'required': 'bool',
        'text': 'str',
        'value': 'object',
        'values': 'list[str]'
    }

    attribute_map = {
        'allow_values_only': 'allowValuesOnly',
        'bus_ob_id': 'busObId',
        'collection_store_entire_row': 'collectionStoreEntireRow',
        'collection_value_field': 'collectionValueField',
        'constraint_xml': 'constraintXml',
        'contents': 'contents',
        'default': 'default',
        'field_id': 'fieldId',
        'is_date_range': 'isDateRange',
        'list_display_option': 'listDisplayOption',
        'list_return_field_id': 'listReturnFieldId',
        'multi_line': 'multiLine',
        'prompt_id': 'promptId',
        'prompt_type': 'promptType',
        'prompt_type_name': 'promptTypeName',
        'required': 'required',
        'text': 'text',
        'value': 'value',
        'values': 'values'
    }

    def __init__(self, allow_values_only=None, bus_ob_id=None, collection_store_entire_row=None, collection_value_field=None, constraint_xml=None, contents=None, default=None, field_id=None, is_date_range=None, list_display_option=None, list_return_field_id=None, multi_line=None, prompt_id=None, prompt_type=None, prompt_type_name=None, required=None, text=None, value=None, values=None, local_vars_configuration=None):  # noqa: E501
        """Prompt - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allow_values_only = None
        self._bus_ob_id = None
        self._collection_store_entire_row = None
        self._collection_value_field = None
        self._constraint_xml = None
        self._contents = None
        self._default = None
        self._field_id = None
        self._is_date_range = None
        self._list_display_option = None
        self._list_return_field_id = None
        self._multi_line = None
        self._prompt_id = None
        self._prompt_type = None
        self._prompt_type_name = None
        self._required = None
        self._text = None
        self._value = None
        self._values = None
        self.discriminator = None

        if allow_values_only is not None:
            self.allow_values_only = allow_values_only
        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if collection_store_entire_row is not None:
            self.collection_store_entire_row = collection_store_entire_row
        if collection_value_field is not None:
            self.collection_value_field = collection_value_field
        if constraint_xml is not None:
            self.constraint_xml = constraint_xml
        if contents is not None:
            self.contents = contents
        if default is not None:
            self.default = default
        if field_id is not None:
            self.field_id = field_id
        if is_date_range is not None:
            self.is_date_range = is_date_range
        if list_display_option is not None:
            self.list_display_option = list_display_option
        if list_return_field_id is not None:
            self.list_return_field_id = list_return_field_id
        if multi_line is not None:
            self.multi_line = multi_line
        if prompt_id is not None:
            self.prompt_id = prompt_id
        if prompt_type is not None:
            self.prompt_type = prompt_type
        if prompt_type_name is not None:
            self.prompt_type_name = prompt_type_name
        if required is not None:
            self.required = required
        if text is not None:
            self.text = text
        if value is not None:
            self.value = value
        if values is not None:
            self.values = values

    @property
    def allow_values_only(self):
        """Gets the allow_values_only of this Prompt.  # noqa: E501


        :return: The allow_values_only of this Prompt.  # noqa: E501
        :rtype: bool
        """
        return self._allow_values_only

    @allow_values_only.setter
    def allow_values_only(self, allow_values_only):
        """Sets the allow_values_only of this Prompt.


        :param allow_values_only: The allow_values_only of this Prompt.  # noqa: E501
        :type: bool
        """

        self._allow_values_only = allow_values_only

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this Prompt.  # noqa: E501


        :return: The bus_ob_id of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this Prompt.


        :param bus_ob_id: The bus_ob_id of this Prompt.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def collection_store_entire_row(self):
        """Gets the collection_store_entire_row of this Prompt.  # noqa: E501


        :return: The collection_store_entire_row of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._collection_store_entire_row

    @collection_store_entire_row.setter
    def collection_store_entire_row(self, collection_store_entire_row):
        """Sets the collection_store_entire_row of this Prompt.


        :param collection_store_entire_row: The collection_store_entire_row of this Prompt.  # noqa: E501
        :type: str
        """

        self._collection_store_entire_row = collection_store_entire_row

    @property
    def collection_value_field(self):
        """Gets the collection_value_field of this Prompt.  # noqa: E501


        :return: The collection_value_field of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._collection_value_field

    @collection_value_field.setter
    def collection_value_field(self, collection_value_field):
        """Sets the collection_value_field of this Prompt.


        :param collection_value_field: The collection_value_field of this Prompt.  # noqa: E501
        :type: str
        """

        self._collection_value_field = collection_value_field

    @property
    def constraint_xml(self):
        """Gets the constraint_xml of this Prompt.  # noqa: E501


        :return: The constraint_xml of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._constraint_xml

    @constraint_xml.setter
    def constraint_xml(self, constraint_xml):
        """Sets the constraint_xml of this Prompt.


        :param constraint_xml: The constraint_xml of this Prompt.  # noqa: E501
        :type: str
        """

        self._constraint_xml = constraint_xml

    @property
    def contents(self):
        """Gets the contents of this Prompt.  # noqa: E501


        :return: The contents of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """Sets the contents of this Prompt.


        :param contents: The contents of this Prompt.  # noqa: E501
        :type: str
        """

        self._contents = contents

    @property
    def default(self):
        """Gets the default of this Prompt.  # noqa: E501


        :return: The default of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this Prompt.


        :param default: The default of this Prompt.  # noqa: E501
        :type: str
        """

        self._default = default

    @property
    def field_id(self):
        """Gets the field_id of this Prompt.  # noqa: E501


        :return: The field_id of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Prompt.


        :param field_id: The field_id of this Prompt.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def is_date_range(self):
        """Gets the is_date_range of this Prompt.  # noqa: E501


        :return: The is_date_range of this Prompt.  # noqa: E501
        :rtype: bool
        """
        return self._is_date_range

    @is_date_range.setter
    def is_date_range(self, is_date_range):
        """Sets the is_date_range of this Prompt.


        :param is_date_range: The is_date_range of this Prompt.  # noqa: E501
        :type: bool
        """

        self._is_date_range = is_date_range

    @property
    def list_display_option(self):
        """Gets the list_display_option of this Prompt.  # noqa: E501


        :return: The list_display_option of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._list_display_option

    @list_display_option.setter
    def list_display_option(self, list_display_option):
        """Sets the list_display_option of this Prompt.


        :param list_display_option: The list_display_option of this Prompt.  # noqa: E501
        :type: str
        """
        allowed_values = ["Auto", "Text", "Combo", "GridList", "SimpleList", "PromptSimpleGrid"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and list_display_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `list_display_option` ({0}), must be one of {1}"  # noqa: E501
                .format(list_display_option, allowed_values)
            )

        self._list_display_option = list_display_option

    @property
    def list_return_field_id(self):
        """Gets the list_return_field_id of this Prompt.  # noqa: E501


        :return: The list_return_field_id of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._list_return_field_id

    @list_return_field_id.setter
    def list_return_field_id(self, list_return_field_id):
        """Sets the list_return_field_id of this Prompt.


        :param list_return_field_id: The list_return_field_id of this Prompt.  # noqa: E501
        :type: str
        """

        self._list_return_field_id = list_return_field_id

    @property
    def multi_line(self):
        """Gets the multi_line of this Prompt.  # noqa: E501


        :return: The multi_line of this Prompt.  # noqa: E501
        :rtype: bool
        """
        return self._multi_line

    @multi_line.setter
    def multi_line(self, multi_line):
        """Sets the multi_line of this Prompt.


        :param multi_line: The multi_line of this Prompt.  # noqa: E501
        :type: bool
        """

        self._multi_line = multi_line

    @property
    def prompt_id(self):
        """Gets the prompt_id of this Prompt.  # noqa: E501


        :return: The prompt_id of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._prompt_id

    @prompt_id.setter
    def prompt_id(self, prompt_id):
        """Sets the prompt_id of this Prompt.


        :param prompt_id: The prompt_id of this Prompt.  # noqa: E501
        :type: str
        """

        self._prompt_id = prompt_id

    @property
    def prompt_type(self):
        """Gets the prompt_type of this Prompt.  # noqa: E501


        :return: The prompt_type of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._prompt_type

    @prompt_type.setter
    def prompt_type(self, prompt_type):
        """Sets the prompt_type of this Prompt.


        :param prompt_type: The prompt_type of this Prompt.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Text", "Number", "DateTime", "Logical", "Binary", "DateOnly", "TimeOnly", "Json", "JsonArray", "Xml", "XmlCollection", "TimeValue"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and prompt_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `prompt_type` ({0}), must be one of {1}"  # noqa: E501
                .format(prompt_type, allowed_values)
            )

        self._prompt_type = prompt_type

    @property
    def prompt_type_name(self):
        """Gets the prompt_type_name of this Prompt.  # noqa: E501


        :return: The prompt_type_name of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._prompt_type_name

    @prompt_type_name.setter
    def prompt_type_name(self, prompt_type_name):
        """Sets the prompt_type_name of this Prompt.


        :param prompt_type_name: The prompt_type_name of this Prompt.  # noqa: E501
        :type: str
        """

        self._prompt_type_name = prompt_type_name

    @property
    def required(self):
        """Gets the required of this Prompt.  # noqa: E501


        :return: The required of this Prompt.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this Prompt.


        :param required: The required of this Prompt.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def text(self):
        """Gets the text of this Prompt.  # noqa: E501


        :return: The text of this Prompt.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Prompt.


        :param text: The text of this Prompt.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def value(self):
        """Gets the value of this Prompt.  # noqa: E501


        :return: The value of this Prompt.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Prompt.


        :param value: The value of this Prompt.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def values(self):
        """Gets the values of this Prompt.  # noqa: E501


        :return: The values of this Prompt.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this Prompt.


        :param values: The values of this Prompt.  # noqa: E501
        :type: list[str]
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Prompt):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Prompt):
            return True

        return self.to_dict() != other.to_dict()
